﻿using ConsoleGraph.WindowBase;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace ConsoleGraph.Controls
{
    public class Button : Control
    {
        
        
        #region Private Field

        private String Text;    
        private ConsoleColor TextColour = ConsoleColor.Black;
        private ConsoleColor SelectedBackgroundColour = ConsoleColor.DarkGray;
        private ConsoleColor SelectedTextColour = ConsoleColor.White;
        private bool Selected = false;

        #endregion

        #region Public Field

        public Action Action;
        public ConsoleColor BackgroundColour = ConsoleColor.Gray;

        #endregion

        /// <summary xml:lang="it">
        /// Crea un controllo di tipo Pulsante
        /// </summary>
        /// <summary xml:lang="en">
        /// Create a button control
        /// </summary>
        /// <param name="x">X</param>
        /// <param name="y">Y</param>
        /// <param name="text">Button Text</param>
        /// <param name="iD">Control ID</param>
        /// <param name="parentWindow">Parent Window</param>
        public Button(int x, int y, String text, String iD, Window parentWindow) : base(x, y, 1, text.Count() + 2, parentWindow, iD)
        {
            Text = text;
            BackgroundColour = parentWindow.BackgroundColour;
            Selectable = true;
        }


        public override void Select()
        {
            if (!Selected)
            {
                Selected = true;
                Draw();
            }
        }

        public override void Unselect()
        {
            if (Selected)
            {
                Selected = false;
                Draw();
            }
        }

        public override void Enter()
        {
            if (Action != null) //If an action has been set
                Action();
        }

        public override void Draw()
        {
            if (Selected)
                WindowManager.WirteText('[' + Text + ']', X, Y, SelectedTextColour, SelectedBackgroundColour);
            else
                WindowManager.WirteText('[' + Text + ']', X, Y, TextColour, BackgroundColour);
        }

        public override void CursorMoveDown()
        {
            Parent.MovetoNextItemDown(X, Y, Width);
        }

        public override void CursorMoveRight()
        {
            Parent.MovetoNextItemRight(X - 1, Y + Width, 3);

        }

        public override void CursorMoveLeft()
        {
            Parent.MovetoNextItemLeft(X - 1, Y, 3);
        }

        public override void CursorMoveUp()
        {
            Parent.MovetoNextItemUp(X, Y, Width);
        }
    }
}
